//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by HelloClient.rc
//
#define IDD_HELLOCLIENT_DIALOG          101
#define IDR_MAINFRAME                   128
#define IDC_MODELABEL                   1000
#define IDC_MODE                        1001
#define IDC_SECURE                      1002
#define IDC_TIMEOUT                     1003
#define IDC_INVOKE                      1004
#define IDC_FLUSH                       1005
#define IDC_SHUTDOWN                    1006
#define IDC_STATUSBAR                   1007
#define IDC_DELAY                       1008

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        130
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1008
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
